function single_mb_batch_job(t)

%-----------------------------------------------------------------------
% function to run model-based fMRI analyses for M&M2017 data set
%
% Author:   Sandra Iglesias
% Created:  2017-12-04
% Copyright (C) 2017 Institute for Biomedical Engineering
%                    University of Zurich and ETH Zurich
%-----------------------------------------------------------------------

addpath C:\Users\Sandra' Iglesias'\Documents\Documents\code\GitTNU\software\spm12\
% spm('defaults','FMRI')
% spm_jobman('initcfg');
dirScans = 'E:\Documents_E\Seminars\M&M_Mantelstudium2017\MandM\MethodsAndModels\2017\Data\Results0001\';
dirFiles = 'E:\Documents_E\Seminars\M&M_Mantelstudium2017\MandM\MethodsAndModels\2017\Data\AllBehav\';
maskScans = 'Sub*';
maskfMRI = '\scandata';
maskGLM  = '\glm\mb_run2';
maskVersion = {'Arrow'};
regressorFile2 =  '\behav\BehavHGF02';
regressorFileModel = '\behav\est_respV';

scans = dir(fullfile(dirScans,maskScans));
scans = {scans.name};
try, iScans; catch; iScans = 1:length(scans); end
disp(['model-based fMRI analysis: ', maskVersion{1},]);
disp(' ');
%% load design information
input_reg = load([dirFiles,scans{t},regressorFile2,'.mat']);
model_reg = load([dirScans,scans{t},regressorFileModel,'.mat']);

dirScan = fullfile(dirScans,scans{t});
dirSubject = ([dirScan, maskGLM]);
mkdir(dirSubject);
%-----------------------------------------------------------------------
% specify design matrix and contrasts
%-----------------------------------------------------------------------
matlabbatch{1}.spm.stats.fmri_spec.dir = {dirSubject};
matlabbatch{1}.spm.stats.fmri_spec.timing.units = 'secs';
matlabbatch{1}.spm.stats.fmri_spec.timing.RT = 2.2;
matlabbatch{1}.spm.stats.fmri_spec.timing.fmri_t = 32;
matlabbatch{1}.spm.stats.fmri_spec.timing.fmri_t0 = 16;


[fp, fn, ext] = fileparts([dirScans,scans{t},'\scandata\swuafmri01.nii']);
matlabbatch{1}.spm.stats.fmri_spec.sess.scans = cellstr(spm_select('ExtFPList', fp, ['^' fn ext], Inf));
matlabbatch{1}.spm.stats.fmri_spec.sess.cond.name = 'Arrow';
matlabbatch{1}.spm.stats.fmri_spec.sess.cond.onset = input_reg.trialOnset;
matlabbatch{1}.spm.stats.fmri_spec.sess.cond.duration = 0;
matlabbatch{1}.spm.stats.fmri_spec.sess.cond.tmod = 0;
matlabbatch{1}.spm.stats.fmri_spec.sess.cond.pmod.name = 'da1';
%%
matlabbatch{1}.spm.stats.fmri_spec.sess.cond.pmod.param = model_reg.traj.da(:,1);
%%
matlabbatch{1}.spm.stats.fmri_spec.sess.cond.pmod.poly = 1;
matlabbatch{1}.spm.stats.fmri_spec.sess.cond.orth = 1;
matlabbatch{1}.spm.stats.fmri_spec.sess.multi = {''};
matlabbatch{1}.spm.stats.fmri_spec.sess.regress = struct('name', {}, 'val', {});
matlabbatch{1}.spm.stats.fmri_spec.sess.multi_reg = {[dirScans,scans{t},maskfMRI,'\rp_afmri02.txt']};
matlabbatch{1}.spm.stats.fmri_spec.sess.hpf = 128;
matlabbatch{1}.spm.stats.fmri_spec.fact = struct('name', {}, 'levels', {});
matlabbatch{1}.spm.stats.fmri_spec.bases.hrf.derivs = [1 1];
matlabbatch{1}.spm.stats.fmri_spec.volt = 1;
matlabbatch{1}.spm.stats.fmri_spec.global = 'None';
matlabbatch{1}.spm.stats.fmri_spec.mthresh = 0.8;
matlabbatch{1}.spm.stats.fmri_spec.mask = {''};
matlabbatch{1}.spm.stats.fmri_spec.cvi = 'AR(1)';
matlabbatch{2}.spm.stats.fmri_est.spmmat(1) = cfg_dep('fMRI model specification: SPM.mat File', substruct('.','val', '{}',{1}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
matlabbatch{2}.spm.stats.fmri_est.write_residuals = 0;
matlabbatch{2}.spm.stats.fmri_est.method.Classical = 1;
matlabbatch{3}.spm.stats.con.spmmat(1) = cfg_dep('Model estimation: SPM.mat File', substruct('.','val', '{}',{2}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
matlabbatch{3}.spm.stats.con.consess{1}.fcon.name = 'da1';
matlabbatch{3}.spm.stats.con.consess{1}.fcon.weights = [0 0 0 1];
matlabbatch{3}.spm.stats.con.consess{1}.fcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{2}.tcon.name = 'pos da1';
matlabbatch{3}.spm.stats.con.consess{2}.tcon.weights = [0 0 0 1];
matlabbatch{3}.spm.stats.con.consess{2}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{3}.tcon.name = 'neg da1';
matlabbatch{3}.spm.stats.con.consess{3}.tcon.weights = [0 0 0 -1];
matlabbatch{3}.spm.stats.con.consess{3}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{4}.fcon.name = 'Arrow';
matlabbatch{3}.spm.stats.con.consess{4}.fcon.weights = 1;
matlabbatch{3}.spm.stats.con.consess{4}.fcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.delete = 0;

spm_jobman('run',matlabbatch);
end


